@@ -1505,14 +1505,30 @@ void Layout::syncDockViewsToScreens()
     //! first step: primary docks must be placed in primary screen free edges
     foreach (auto containment, m_containments) {
         if (isLatteContainment(containment)) {
-            int screenId = containment->screen();
+            int screenId = 0;
 
-            if (screenId == -1) {
-                screenId = containment->lastScreen();
+            //! valid screen id
+            if (dockViewExists(containment)) {
+                screenId = m_corona->screenPool()->id(m_dockViews[containment]->currentScreen());
+            } else {
+                screenId = containment->screen();
+
+                if (screenId == -1) {
+                    screenId = containment->lastScreen();
+                }
             }
 
-            bool onPrimary = containment->config().readEntry("onPrimary", true);
-            Plasma::Types::Location location = static_cast<Plasma::Types::Location>((int)containment->config().readEntry("location", (int)Plasma::Types::BottomEdge));
+            bool onPrimary{true};
+
+            //! valid onPrimary flag
+            if (dockViewExists(containment)) {
+                onPrimary = m_dockViews[containment]->onPrimary();
+            } else {
+                onPrimary = containment->config().readEntry("onPrimary", true);
+            }
+
+            //! valid location
+            Plasma::Types::Location location = containment->location();
 
             if (onPrimary && !futureDocksLocations[prmScreenName].contains(location)) {
                 futureDocksLocations[prmScreenName].append(location);
@@ -1524,14 +1540,30 @@ void Layout::syncDockViewsToScreens()
     //! second step: explicit docks must be placed in their screens if the screen edge is free
     foreach (auto containment, m_containments) {
         if (isLatteContainment(containment)) {
-            int screenId = containment->screen();
+            int screenId = 0;
 
-            if (screenId == -1) {
-                screenId = containment->lastScreen();
+            //! valid screen id
+            if (dockViewExists(containment)) {
+                screenId = m_corona->screenPool()->id(m_dockViews[containment]->currentScreen());
+            } else {
+                screenId = containment->screen();
+
+                if (screenId == -1) {
+                    screenId = containment->lastScreen();
+                }
             }
 
-            bool onPrimary = containment->config().readEntry("onPrimary", true);
-            Plasma::Types::Location location = static_cast<Plasma::Types::Location>((int)containment->config().readEntry("location", (int)Plasma::Types::BottomEdge));
+            bool onPrimary{true};
+
+            //! valid onPrimary flag
+            if (dockViewExists(containment)) {
+                onPrimary = m_dockViews[containment]->onPrimary();
+            } else {
+                onPrimary = containment->config().readEntry("onPrimary", true);
+            }
+
+            //! valid location
+            Plasma::Types::Location location = containment->location();
 
             if (!onPrimary) {
                 QString expScreenName = m_corona->screenPool()->connector(screenId);
